==> zbxe.beta.0.1.4.tgz: zbxe/common/lang/zh-CN.lang.php <==
<?php
    /**
     * @file   common/lang/zh-CN.lang.php
     * @author zero (zero@nzeo.com)
     * @brief  简体中文语言包 (只收录基本内容)
     **/

    // 基本使用的 action 语言
    $lang->cmd_write = '发表新帖';
    $lang->cmd_reply = '回复';
    $lang->cmd_delete = '删除';
    $lang->cmd_modify = '修改';
    $lang->cmd_edit = '编辑';
    $lang->cmd_view = '查看';
    $lang->cmd_view_all = '全部查看';
    $lang->cmd_list = '目录';
    $lang->cmd_prev = '上一页';
    $lang->cmd_next = '下一页';
    $lang->cmd_send_trackback = '发送引用';
    $lang->cmd_registration = $lang->cmd_submit = '提交';
    $lang->cmd_comment_registration = '提交评论';
    $lang->cmd_insert = '添加';
    $lang->cmd_save = '保存';
    $lang->cmd_input = '输入';
    $lang->cmd_search = '搜索';
    $lang->cmd_cancel = '取消';
    $lang->cmd_back = '返回';
    $lang->cmd_vote = '推荐';
    $lang->cmd_move = '查看';
    $lang->cmd_move_up = '向上';
    $lang->cmd_move_down = '向下';
    $lang->cmd_add_indent = '拉长';
    $lang->cmd_remove_indent = '缩短';
    $lang->cmd_management = '管理';
    $lang->cmd_make = '生成';
    $lang->cmd_select = '选择';
    $lang->cmd_select_all = '全部选择';
    $lang->cmd_unselect_all = '全部解除';
    $lang->cmd_close_all = '全部关闭';
    $lang->cmd_open_all = '全部打开';
    $lang->cmd_reload = '从新载入';
    $lang->cmd_close = '关闭';
    $lang->cmd_open = '打开';
    $lang->cmd_setup = '设置';
    $lang->cmd_option = '选项';
    $lang->cmd_apply = '应用';
    $lang->cmd_open_calendar = '选择日期';
    $lang->cmd_send = '发送';
    $lang->cmd_print = '打印';
    $lang->cmd_scrap = '收藏';
    $lang->cmd_preview = '预览';
    $lang->cmd_reset = '初始化';
    $lang->cmd_remake_cache = "重新生成缓冲文件";

    $lang->enable = '可用';
    $lang->disable = '禁用';

    // 基本词语
    $lang->no = '编号';
    $lang->notice = '公告';
    $lang->secret = '密帖';
    $lang->category = '分类';
    $lang->document_srl = '文章编号';
    $lang->user_id = '用户名';
    $lang->author = '制作';
    $lang->password = '密码';
    $lang->password1 = '密码';
    $lang->password2 = '确认密码';
    $lang->admin_id = '管理员ID';
    $lang->writer = '作者';
    $lang->user_name = '姓名';
    $lang->nick_name = '昵称';
    $lang->email_address = '电子邮件';
    $lang->homepage = '主页';
    $lang->blog = '博客';
    $lang->birthday = '生日';
    $lang->browser_title = '浏览器标题';
    $lang->title = '标题';
    $lang->title_content = '标题+内容';
    $lang->content = '内容';
    $lang->document = '文章';
    $lang->comment = '评论';
    $lang->description = '说明';
    $lang->trackback = '引用';
    $lang->tag = '标签';
    $lang->allow_comment = '允许评论';
    $lang->lock_comment = '关闭评论';
    $lang->allow_trackback = '允许引用';
    $lang->uploaded_file = '附件';
    $lang->grant = '权限';
    $lang->target = '目标';
    $lang->total = '全部';
    $lang->total_count = '总数';
    $lang->ipaddress = 'IP地址';
    $lang->path = '路径';
    $lang->cart = '选择项目';
    $lang->friend = '好友';
    $lang->notify = '通告';

    $lang->mid = '模块名称';
    $lang->layout = '布局';
    $lang->widget = '控件 ';
    $lang->module = '模块';
    $lang->skin = '皮肤';
    $lang->colorset = '颜色设定';
    $lang->extra_vars = '扩展变数';

    $lang->document_url = '文章地址';
    $lang->trackback_url = '引用地址';
    $lang->blog_name = '博客名称';
    $lang->excerpt = '载自';

    $lang->document_count = '帖子数';
    $lang->page_count = '页数';
    $lang->list_count = '目录数';
    $lang->readed_count = '查看';
    $lang->voted_count = '推荐';
    $lang->member_count = '会员数';
    $lang->date = '日期';
    $lang->regdate = '登录日期';
    $lang->last_update = '最后更新';
    $lang->signup_date = '注册日期';
    $lang->last_login = '最近登陆';
    $lang->first_page = '第一页';
    $lang->last_page = '最后一页';
    $lang->search_target = '搜索目标';
    $lang->search_keyword = '关键字';
    $lang->is_default = '默认';

    $lang->no_documents = '现没有主题。';

    $lang->board_manager = '版面管理';
    $lang->member_manager = '会员管理';
    $lang->layout_manager = '布局管理';

    $lang->use = '使用';
    $lang->notuse = '未使用';
    $lang->not_exists = '无';

    $lang->unit_sec = '秒';
    $lang->unit_min = '分';
    $lang->unit_hour = '时';
    $lang->unit_day = '日';
    $lang->unit_week = '周';
    $lang->unit_month = '月';
    $lang->unit_year = '年';

    // 说明
    $lang->about_tag = '用逗号分隔多个标签';
    $lang->about_layout = '布局是布置模块的外观，在上端布局菜里单可以进行管理';

    // 信息
    $lang->msg_call_server = '系统正在链接服务器，请稍后。';
    $lang->msg_db_not_setted = '还没有设定 DB';
    $lang->msg_invalid_queryid = 'Query ID值指定错误';
    $lang->msg_not_permitted = '没有权限';
    $lang->msg_input_password = '请输入密码';
    $lang->msg_invalid_document = '出错的文章编号';
    $lang->msg_invalid_request = '出错的请求';
    $lang->msg_invalid_password = '密码错误';
    $lang->msg_error_occured = '发生错误';
    $lang->msg_not_founded = '没有找到相关内容';
    $lang->msg_no_result = '找不到和您查询的相符结果';

    $lang->msg_not_permitted_act = '没有权限执行 action命令';
    $lang->msg_module_is_not_exists = '找不到您查询的模块';
    $lang->msg_module_is_not_standalone = '您请求的模块不能单独执行';

    $lang->success_registed = '提交成功！';
    $lang->success_updated = '修改成功！';
    $lang->success_deleted = '删除成功！';
    $lang->success_voted = '推荐成功！';
    $lang->success_moved = '移动成功！';
    $lang->success_sended = '发送成功！';
    $lang->success_reset = '初始化成功';
    $lang->success_leaved = '注销成功！';
	
    $lang->fail_to_delete = '删除成功！';
    $lang->fail_to_move = '移动成功！';
	
    $lang->failed_voted = '您不能推荐！';
    $lang->fail_to_delete_have_children = '不能删除有回复的评论！';

    $lang->confirm_submit = '确定要提交吗?';
    $lang->confirm_logout = '确定要退出吗?';
    $lang->confirm_vote = '确定要推荐吗?';
    $lang->confirm_delete = '确定要删除吗?';
    $lang->confirm_move = '确定要移动吗?';
    $lang->confirm_reset = '确定要初始化吗?';
    $lang->confirm_leave = '确定要注销吗?';

    $lang->column_type = '格式';
    $lang->column_type_list['text'] = '单行文本输入区(text)';
    $lang->column_type_list['homepage'] = '网址格式 (url)';
    $lang->column_type_list['email_address'] = '邮件格式 (email)';
    $lang->column_type_list['tel'] = '电话号码格式 (phone)';
    $lang->column_type_list['textarea'] = '多行文本框 (textarea)';
    $lang->column_type_list['checkbox'] = '复选框 (checkbox)';
    $lang->column_type_list['select'] = '下拉列表框 (select)';
    $lang->column_type_list['kr_zip'] = '韩国地址 (zip)';
    $lang->column_type_list['date'] = '日期 (年月日)';
    //$lang->column_type_list['jp_zip'] = '日本地址 (zip)';
    $lang->column_name = '项目名';
    $lang->column_title = '项目标题';
    $lang->default_value = '缺省值';
    $lang->is_active = '激活';
    $lang->is_required = '必填';

    // 在xml filter使用的 javascript用 alert msg
    $lang->filter->isnull = '请输入%s';
    $lang->filter->outofrange = '请确认%s字数';
    $lang->filter->equalto = '%s值有误。';
    $lang->filter->invalid_email = '%s格式有误。（例：zbxe@zeroboard.com)';
    $lang->filter->invalid_user_id = $lang->filter->invalid_userid = "%s只能用英文，数字和 _，首个字符必须是英文字母。";
    $lang->filter->invalid_homepage = '%s格式有误。（例： http://www.zeroboard.com)';
    $lang->filter->invalid_korean = '%s只能输入中文';
    $lang->filter->invalid_korean_number = '%s只能输入中文或数字';
    $lang->filter->invalid_alpha = '%s只能输入英文字母';
    $lang->filter->invalid_alpha_number = '%s只能输入英文或数字';
    $lang->filter->invalid_number = '%s只能输入数字';
?>

==> zbxe.beta.0.1.5.tgz: zbxe/common/lang/zh-CN.lang.php <==
<?php
    /**
     * @file   common/lang/zh-CN.lang.php
     * @author zero (zero@nzeo.com)
     * @brief  简体中文语言包 (只收录基本内容)
     **/

    // 基本使用的 action 语言
    $lang->cmd_write = '发表新帖';
    $lang->cmd_reply = '回复';
    $lang->cmd_delete = '删除';
    $lang->cmd_modify = '修改';
    $lang->cmd_edit = '编辑';
    $lang->cmd_view = '查看';
    $lang->cmd_view_all = '全部查看';
    $lang->cmd_list = '目录';
    $lang->cmd_prev = '上一页';
    $lang->cmd_next = '下一页';
    $lang->cmd_send_trackback = '发送引用';
    $lang->cmd_registration = $lang->cmd_submit = '提交';
    $lang->cmd_comment_registration = '提交评论';
    $lang->cmd_insert = '添加';
    $lang->cmd_save = '保存';
    $lang->cmd_input = '输入';
    $lang->cmd_search = '搜索';
    $lang->cmd_cancel = '取消';
    $lang->cmd_back = '返回';
    $lang->cmd_vote = '推荐';
    $lang->cmd_copy = '副本';
    $lang->cmd_move = '查看';
    $lang->cmd_move_up = '向上';
    $lang->cmd_move_down = '向下';
    $lang->cmd_add_indent = '拉长';
    $lang->cmd_remove_indent = '缩短';
    $lang->cmd_management = '管理';
    $lang->cmd_make = '生成';
    $lang->cmd_select = '选择';
    $lang->cmd_select_all = '全部选择';
    $lang->cmd_unselect_all = '全部解除';
    $lang->cmd_close_all = '全部关闭';
    $lang->cmd_open_all = '全部打开';
    $lang->cmd_reload = '从新载入';
    $lang->cmd_close = '关闭';
    $lang->cmd_open = '打开';
    $lang->cmd_setup = '设置';
    $lang->cmd_option = '选项';
    $lang->cmd_apply = '应用';
    $lang->cmd_open_calendar = '选择日期';
    $lang->cmd_send = '发送';
    $lang->cmd_print = '打印';
    $lang->cmd_scrap = '收藏';
    $lang->cmd_preview = '预览';
    $lang->cmd_reset = '初始化';
    $lang->cmd_remake_cache = "重新生成缓冲文件";

    $lang->enable = '可用';
    $lang->disable = '禁用';

    // 基本词语
    $lang->no = '编号';
    $lang->notice = '公告';
    $lang->secret = '密帖';
    $lang->category = '分类';
    $lang->document_srl = '文章编号';
    $lang->user_id = '用户名';
    $lang->author = '制作';
    $lang->password = '密码';
    $lang->password1 = '密码';
    $lang->password2 = '确认密码';
    $lang->admin_id = '管理员ID';
    $lang->writer = '作者';
    $lang->user_name = '姓名';
    $lang->nick_name = '昵称';
    $lang->email_address = '电子邮件';
    $lang->homepage = '主页';
    $lang->blog = '博客';
    $lang->birthday = '生日';
    $lang->browser_title = '浏览器标题';
    $lang->title = '标题';
    $lang->title_content = '标题+内容';
    $lang->content = '内容';
    $lang->document = '文章';
    $lang->comment = '评论';
    $lang->description = '说明';
    $lang->trackback = '引用';
    $lang->tag = '标签';
    $lang->allow_comment = '允许评论';
    $lang->lock_comment = '关闭评论';
    $lang->allow_trackback = '允许引用';
    $lang->uploaded_file = '附件';
    $lang->grant = '权限';
    $lang->target = '目标';
    $lang->total = '全部';
    $lang->total_count = '总数';
    $lang->ipaddress = 'IP地址';
    $lang->path = '路径';
    $lang->cart = '选择项目';
    $lang->friend = '好友';
    $lang->notify = '通告';

    $lang->mid = '模块名称';
    $lang->layout = '布局';
    $lang->widget = '控件 ';
    $lang->module = '模块';
    $lang->skin = '皮肤';
    $lang->colorset = '颜色设定';
    $lang->extra_vars = '扩展变数';

    $lang->document_url = '文章地址';
    $lang->trackback_url = '引用地址';
    $lang->blog_name = '博客名称';
    $lang->excerpt = '载自';

    $lang->document_count = '帖子数';
    $lang->page_count = '页数';
    $lang->list_count = '目录数';
    $lang->readed_count = '查看';
    $lang->voted_count = '推荐';
    $lang->member_count = '会员数';
    $lang->date = '日期';
    $lang->regdate = '登录日期';
    $lang->last_update = '最后更新';
    $lang->signup_date = '注册日期';
    $lang->last_login = '最近登录';
    $lang->first_page = '第一页';
    $lang->last_page = '最后一页';
    $lang->search_target = '搜索目标';
    $lang->search_keyword = '关键字';
    $lang->is_default = '默认';

    $lang->no_documents = '现没有主题。';

    $lang->board_manager = '版面管理';
    $lang->member_manager = '会员管理';
    $lang->layout_manager = '布局管理';

    $lang->use = '使用';
    $lang->notuse = '未使用';
    $lang->not_exists = '无';

    $lang->unit_sec = '秒';
    $lang->unit_min = '分';
    $lang->unit_hour = '时';
    $lang->unit_day = '日';
    $lang->unit_week = '周';
    $lang->unit_month = '月';
    $lang->unit_year = '年';

    // 说明
    $lang->about_tag = '用逗号分隔多个标签';
    $lang->about_layout = '布局是布置模块的外观，在上端布局菜里单可以进行管理';

    // 信息
    $lang->msg_call_server = '系统正在链接服务器，请稍后。';
    $lang->msg_db_not_setted = '还没有设定 DB';
    $lang->msg_invalid_queryid = 'Query ID值指定错误';
    $lang->msg_not_permitted = '没有权限';
    $lang->msg_input_password = '请输入密码';
    $lang->msg_invalid_document = '出错的文章编号';
    $lang->msg_invalid_request = '出错的请求';
    $lang->msg_invalid_password = '密码错误';
    $lang->msg_error_occured = '发生错误';
    $lang->msg_not_founded = '没有找到相关内容';
    $lang->msg_no_result = '找不到和您查询的相符结果';

    $lang->msg_not_permitted_act = '没有权限执行 action命令';
    $lang->msg_module_is_not_exists = '找不到您查询的模块';
    $lang->msg_module_is_not_standalone = '您请求的模块不能单独执行';

    $lang->success_registed = '提交成功！';
    $lang->success_updated = '修改成功！';
    $lang->success_deleted = '删除成功！';
    $lang->success_voted = '推荐成功！';
    $lang->success_moved = '移动成功！';
    $lang->success_sended = '发送成功！';
    $lang->success_reset = '初始化成功';
    $lang->success_leaved = '注销成功！';
	
    $lang->fail_to_delete = '删除成功！';
    $lang->fail_to_move = '移动成功！';
	
    $lang->failed_voted = '您不能推荐！';
    $lang->fail_to_delete_have_children = '不能删除有回复的评论！';

    $lang->confirm_submit = '确定要提交吗?';
    $lang->confirm_logout = '确定要退出吗?';
    $lang->confirm_vote = '确定要推荐吗?';
    $lang->confirm_delete = '确定要删除吗?';
    $lang->confirm_move = '确定要移动吗?';
    $lang->confirm_reset = '确定要初始化吗?';
    $lang->confirm_leave = '确定要注销吗?';

    $lang->column_type = '格式';
    $lang->column_type_list['text'] = '单行文本输入区(text)';
    $lang->column_type_list['homepage'] = '网址格式 (url)';
    $lang->column_type_list['email_address'] = '邮件格式 (email)';
    $lang->column_type_list['tel'] = '电话号码格式 (phone)';
    $lang->column_type_list['textarea'] = '多行文本框 (textarea)';
    $lang->column_type_list['checkbox'] = '复选框 (checkbox)';
    $lang->column_type_list['select'] = '下拉列表框 (select)';
    $lang->column_type_list['kr_zip'] = '韩国地址 (zip)';
    $lang->column_type_list['date'] = '日期 (年月日)';
    //$lang->column_type_list['jp_zip'] = '日本地址 (zip)';
    $lang->column_name = '项目名';
    $lang->column_title = '项目标题';
    $lang->default_value = '缺省值';
    $lang->is_active = '激活';
    $lang->is_required = '必填';

    // 在xml filter使用的 javascript用 alert msg
    $lang->filter->isnull = '请输入%s';
    $lang->filter->outofrange = '请确认%s字数';
    $lang->filter->equalto = '%s值有误。';
    $lang->filter->invalid_email = '%s格式有误。（例：zbxe@zeroboard.com)';
    $lang->filter->invalid_user_id = $lang->filter->invalid_userid = "%s只能用英文，数字和 _，首个字符必须是英文字母。";
    $lang->filter->invalid_homepage = '%s格式有误。（例： http://www.zeroboard.com)';
    $lang->filter->invalid_korean = '%s只能输入中文';
    $lang->filter->invalid_korean_number = '%s只能输入中文或数字';
    $lang->filter->invalid_alpha = '%s只能输入英文字母';
    $lang->filter->invalid_alpha_number = '%s只能输入英文或数字';
    $lang->filter->invalid_number = '%s只能输入数字';
?>
